==> qtjambi-gamepad-5.15.7-sources.jar: io/qt/gamepad/QtJambi_LibraryUtilities.java <==
package io.qt.gamepad;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 5;

    final static int qtMinorVersion = 15;

    final static int qtJambiPatch = 7;

    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadUtilityLibrary("libGLESv2", io.qt.QtUtilities.LibraryRequirementMode.Optional, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("libEGL", io.qt.QtUtilities.LibraryRequirementMode.Optional, "windows");
            io.qt.QtUtilities.loadQtLibrary("Widgets", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos");
            io.qt.QtUtilities.loadQtLibrary("PrintSupport", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos");
            io.qt.QtUtilities.loadQtLibrary("Svg", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("VirtualKeyboard", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("DBus", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos", "linux");
            io.qt.QtUtilities.loadQtLibrary("Network", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("Gui", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Gamepad", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtJambiLibrary("Gamepad");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }
    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-gamepad-5.15.11-sources.jar: io/qt/gamepad/QtJambi_LibraryUtilities.java <==
package io.qt.gamepad;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 5;

    final static int qtMinorVersion = 15;

    final static int qtJambiPatch = 11;

    final static io.qt.InternalAccess internal;

    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("DBus", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos", "linux");
            io.qt.QtUtilities.loadQtLibrary("Network", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("OpenGL", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("PrintSupport", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos");
            io.qt.QtUtilities.loadQtLibrary("Qml", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("QmlModels", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("Quick", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("Svg", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("VirtualKeyboard", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("WaylandClient", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("WaylandEglClientHwIntegration", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("Widgets", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux", "macos");
            io.qt.QtUtilities.loadQtLibrary("WlShellIntegration", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadUtilityLibrary("libGLESv2", io.qt.QtUtilities.LibraryRequirementMode.Optional, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("libEGL", io.qt.QtUtilities.LibraryRequirementMode.Optional, "windows");
            io.qt.QtUtilities.loadQtLibrary("Gui", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Gamepad", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtJambiLibrary("Gamepad");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
